==> alg-common-2.4.11-20190801.073039-1-sources.jar: cn/com/duiba/nezha/alg/common/model/pacing/AdvertOrientInfo.java <==
package cn.com.duiba.nezha.alg.common.model.pacing;

import java.util.Objects;

public class AdvertOrientInfo {

    Long advertId;
    Long orientId;
    Double costConvertBias;
    Double cost;

    public AdvertOrientInfo() {
    }

    public AdvertOrientInfo(Long advertId, Long orientId) {
        this.advertId = advertId;
        this.orientId = orientId;
    }

    public AdvertOrientInfo(Long advertId, Long orientId, Double costConvertBias, Double cost) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.costConvertBias = costConvertBias;
        this.cost = cost;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public Double getCostConvertBias() {
        return costConvertBias;
    }

    public void setCostConvertBias(Double costConvertBias) {
        this.costConvertBias = costConvertBias;
    }

    public Double getCost() {
        return cost;
    }

    public void setCost(Double cost) {
        this.cost = cost;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AdvertOrientInfo that = (AdvertOrientInfo) o;
        return Objects.equals(advertId, that.advertId) &&
                Objects.equals(orientId, that.orientId);
    }

    @Override
    public String toString() {
        return "AdvertOrientInfo{" +
                "advertId=" + advertId +
                ", orientId=" + orientId +
                '}';
    }

    @Override
    public int hashCode() {
        return Objects.hash(advertId, orientId);
    }
}

==> alg-common-4.0.3-20200330.092308-1-sources.jar: cn/com/duiba/nezha/alg/common/model/pacing/AdvertOrientInfo.java <==
package cn.com.duiba.nezha.alg.common.model.pacing;

import java.util.Objects;
import java.util.Set;

public class AdvertOrientInfo {

    Long advertId;
    Long orientId;
    Double costConvertBias;
    Double cost;
    Set<Integer> matchType;//0重点媒体定向1表示统计2表示预估3表示协同过滤

    public AdvertOrientInfo() {
    }


    public AdvertOrientInfo(Long advertId, Long orientId) {
        this.advertId = advertId;
        this.orientId = orientId;
    }

    public AdvertOrientInfo(Long advertId, Long orientId, Set<Integer> matchType) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.matchType = matchType;
    }

    public AdvertOrientInfo(Long advertId, Long orientId, Double costConvertBias, Double cost) {
        this.advertId = advertId;
        this.orientId = orientId;
        this.costConvertBias = costConvertBias;
        this.cost = cost;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getOrientId() {
        return orientId;
    }

    public void setOrientId(Long orientId) {
        this.orientId = orientId;
    }

    public Double getCostConvertBias() {
        return costConvertBias;
    }

    public void setCostConvertBias(Double costConvertBias) {
        this.costConvertBias = costConvertBias;
    }

    public Double getCost() {
        return cost;
    }

    public void setCost(Double cost) {
        this.cost = cost;
    }

    public void setMatchType(Set<Integer> matchType) {
        this.matchType = matchType;
    }

    public Set<Integer> getMatchType() {
        return matchType;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AdvertOrientInfo that = (AdvertOrientInfo) o;
        return Objects.equals(advertId, that.advertId) &&
                Objects.equals(orientId, that.orientId);
    }

    @Override
    public String toString() {
        return "AdvertOrientInfo{" +
                "advertId=" + advertId +
                ", orientId=" + orientId +
                ", matchType=" + matchType +
                '}';
    }

    @Override
    public int hashCode() {
        return Objects.hash(advertId, orientId);
    }
}
